function rock2D = averageRock(rock, g_top)
% Average version of rock for use in vertical averaging
%
% SYNOPSIS:
%   rock = averageRock(rock, g_top)
%
% PARAMETERS:
%   rock    - rock structure for 3D grid
%
%   g_top   - top surface 2D grid as defined by function 'topSurfaceGrid'.
%
% RETURNS:
%   rock2D  - rock structure with porosities and (lateral) permeability
%             averaged for each column

%{
Copyright 2009, 2010, 2011, 2012 SINTEF ICT, Applied Mathematics.

This file is part of The MATLAB Reservoir Simulation Toolbox (MRST).

MRST is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

MRST is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MRST.  If not, see <http://www.gnu.org/licenses/>.
%}

c = g_top.columns;
cP = g_top.cells.columnPos;

colNo = rldecode(1:g_top.cells.num, cP(2:end)- cP(1:(end-1)),2).';


rock2D.poro = accumarray(colNo, rock.poro(c.cells).*c.dz)./accumarray(colNo,c.dz);
rock2D.perm = accumarray(colNo, rock.perm(c.cells,1).*c.dz)./accumarray(colNo,c.dz);
%{
X = sparse(colNo, 1:numel(c.cells), 1) * ...
    [rock.poro(c.cells), rock.perm(c.cells,:), ones([numel(c.cells), 1])];

X = bsxfun(@rdivide, X(:,1:end-1), X(:,end));

rock2D.poro = X(:,1);
rock2D.perm = X(:,2:end);
%}
end
